"use strict";
var html_reporter_1 = require("./reporters/html-reporter");
var log_1 = require("./log");
exports.EReportType = {
    NOTE: 'NOTE',
    WARNING: 'WARNING',
    ERROR: 'ERROR',
};
exports.EExecutionStep = {
    INIT: 'INIT',
    SCENARIO: 'SCENARIO',
    SETUP: 'SETUP',
    TEARDOWN: 'TEARDOWN',
};
var Reports = (function () {
    function Reports() {
        this._step = exports.EExecutionStep.INIT;
        this._reports = new Map();
        this._reports.set(exports.EExecutionStep.INIT, []);
        this._reports.set(exports.EExecutionStep.SCENARIO, []);
        this._reports.set(exports.EExecutionStep.SETUP, []);
        this._reports.set(exports.EExecutionStep.TEARDOWN, []);
        this._reporters = new Map();
        this._reporters.set('html', new html_reporter_1.HtmlReporter());
    }
    Reports.prototype._setStep = function (executionStep) {
        this._step = executionStep;
    };
    Reports.prototype._setTest = function (testData) {
        this._currentTestData = testData;
    };
    Reports.prototype._setInstanceNumber = function (instance) {
        this._instance = instance;
    };
    Reports.prototype.warning = function (params) {
        params.type = exports.EReportType.WARNING;
        this._report(params);
    };
    Reports.prototype.note = function (params) {
        params.type = exports.EReportType.NOTE;
        this._report(params);
    };
    Reports.prototype.error = function (params) {
        params.type = exports.EReportType.ERROR;
        this._report(params);
    };
    Reports.prototype._report = function (params) {
        params.timestamp = new Date();
        params.instance = this._instance;
        this._reports.get(this._step).push(params);
    };
    Reports.prototype.saveReport = function (reports, testName, reporters, path) {
        var _this = this;
        log_1.logDebug("saveReport called for test: " + testName);
        if (reporters.length === 0 || !path) {
            log_1.logDebug('No reports configured...');
            return;
        }
        reporters.forEach(function (reporterName) {
            log_1.logDebug("Writing report using " + reporterName + " reporter...");
            var reporter = _this._reporters.get(reporterName);
            log_1.logDebug("Reporter " + reporterName + " exists: " + !!reporter);
            if (reporter) {
                reporter.writeTestReport(testName, reports, path);
            }
        });
    };
    return Reports;
}());
exports.Reports = Reports;
//# sourceMappingURL=reports.js.map