"use strict";
var DDPClient = require('ddp');
var url_1 = require("url");
var crypto_1 = require("crypto");
var MeteorStressTest = (function () {
    function MeteorStressTest() {
        this.subscriptions = {};
    }
    MeteorStressTest.prototype.urlToDDPOptions = function (url) {
        var parsedUrl = url_1.parse(url);
        var pathname = parsedUrl.pathname.substr(1);
        var isSsl = /^https/.test(parsedUrl.protocol);
        var port = Number(parsedUrl.port);
        if (!port) {
            port = (isSsl) ? 443 : 80;
        }
        return {
            path: pathname,
            host: parsedUrl.hostname,
            port: port,
            use_ssl: isSsl
        };
    };
    MeteorStressTest.prototype.connect = function (ddpUrl) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            _this.ddpClient = new DDPClient(_this.urlToDDPOptions(ddpUrl));
            _this.ddpClient.connect(function (error) {
                if (error) {
                    reject(error);
                    return;
                }
                resolve(_this.ddpClient);
            });
        });
    };
    MeteorStressTest.prototype.disconnect = function () {
        return this.ddpClient.close();
    };
    MeteorStressTest.prototype.unsubscribe = function (subscriptionName) {
        return this.ddpClient.unsubscribe(this.subscriptions[subscriptionName]);
    };
    MeteorStressTest.prototype.subscribe = function (subscriptionName) {
        var _this = this;
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        return new Promise(function (resolve, reject) {
            var isDone = false;
            var result = _this.ddpClient.subscribe(subscriptionName, args, function (err) {
                if (err) {
                    reject(err);
                }
                else {
                    isDone = true;
                    resolve(result);
                }
            });
            _this.subscriptions[subscriptionName] = result;
        });
    };
    MeteorStressTest.prototype.call = function (methodName) {
        var _this = this;
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        return new Promise(function (resolve, reject) {
            _this.ddpClient.call(methodName, args, function (err, result) {
                if (err) {
                    reject(err);
                }
                else {
                    resolve(result);
                }
            });
        });
    };
    MeteorStressTest.prototype.login = function (username, email, password) {
        var user = this.getValidUser(email, username);
        return this.call('login', {
            user: user,
            password: this.hashPassword(password)
        });
    };
    MeteorStressTest.prototype.getValidUser = function (email, username) {
        if (username && typeof username === 'string' && username !== '') {
            return { username: username };
        }
        else if (email && typeof email === 'string' && email !== '') {
            return { email: email };
        }
        else {
            throw "You must provide either email or username";
        }
    };
    MeteorStressTest.prototype.hashPassword = function (password) {
        var hash = crypto_1.createHash('sha256');
        hash.update(password);
        return {
            digest: hash.digest('hex'),
            algorithm: 'sha-256',
        };
    };
    Object.defineProperty(MeteorStressTest.prototype, "ddp", {
        get: function () {
            return this.ddpClient;
        },
        enumerable: true,
        configurable: true
    });
    return MeteorStressTest;
}());
exports.MeteorStressTest = MeteorStressTest;
//# sourceMappingURL=meteor.js.map